# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class PatchedrpmUlnRemote(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'url': 'str',
        'ca_cert': 'str',
        'client_cert': 'str',
        'client_key': 'str',
        'tls_validation': 'bool',
        'proxy_url': 'str',
        'proxy_username': 'str',
        'proxy_password': 'str',
        'username': 'str',
        'password': 'str',
        'pulp_labels': 'dict(str, str)',
        'download_concurrency': 'int',
        'max_retries': 'int',
        'policy': 'PolicyEnum',
        'total_timeout': 'float',
        'connect_timeout': 'float',
        'sock_connect_timeout': 'float',
        'sock_read_timeout': 'float',
        'headers': 'list[object]',
        'rate_limit': 'int',
        'uln_server_base_url': 'str'
    }

    attribute_map = {
        'name': 'name',
        'url': 'url',
        'ca_cert': 'ca_cert',
        'client_cert': 'client_cert',
        'client_key': 'client_key',
        'tls_validation': 'tls_validation',
        'proxy_url': 'proxy_url',
        'proxy_username': 'proxy_username',
        'proxy_password': 'proxy_password',
        'username': 'username',
        'password': 'password',
        'pulp_labels': 'pulp_labels',
        'download_concurrency': 'download_concurrency',
        'max_retries': 'max_retries',
        'policy': 'policy',
        'total_timeout': 'total_timeout',
        'connect_timeout': 'connect_timeout',
        'sock_connect_timeout': 'sock_connect_timeout',
        'sock_read_timeout': 'sock_read_timeout',
        'headers': 'headers',
        'rate_limit': 'rate_limit',
        'uln_server_base_url': 'uln_server_base_url'
    }

    def __init__(self, name=None, url=None, ca_cert=None, client_cert=None, client_key=None, tls_validation=None, proxy_url=None, proxy_username=None, proxy_password=None, username=None, password=None, pulp_labels=None, download_concurrency=None, max_retries=None, policy=None, total_timeout=None, connect_timeout=None, sock_connect_timeout=None, sock_read_timeout=None, headers=None, rate_limit=None, uln_server_base_url=None, local_vars_configuration=None):  # noqa: E501
        """PatchedrpmUlnRemote - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._url = None
        self._ca_cert = None
        self._client_cert = None
        self._client_key = None
        self._tls_validation = None
        self._proxy_url = None
        self._proxy_username = None
        self._proxy_password = None
        self._username = None
        self._password = None
        self._pulp_labels = None
        self._download_concurrency = None
        self._max_retries = None
        self._policy = None
        self._total_timeout = None
        self._connect_timeout = None
        self._sock_connect_timeout = None
        self._sock_read_timeout = None
        self._headers = None
        self._rate_limit = None
        self._uln_server_base_url = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if url is not None:
            self.url = url
        self.ca_cert = ca_cert
        self.client_cert = client_cert
        self.client_key = client_key
        if tls_validation is not None:
            self.tls_validation = tls_validation
        self.proxy_url = proxy_url
        self.proxy_username = proxy_username
        self.proxy_password = proxy_password
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if pulp_labels is not None:
            self.pulp_labels = pulp_labels
        self.download_concurrency = download_concurrency
        self.max_retries = max_retries
        if policy is not None:
            self.policy = policy
        self.total_timeout = total_timeout
        self.connect_timeout = connect_timeout
        self.sock_connect_timeout = sock_connect_timeout
        self.sock_read_timeout = sock_read_timeout
        if headers is not None:
            self.headers = headers
        self.rate_limit = rate_limit
        self.uln_server_base_url = uln_server_base_url

    @property
    def name(self):
        """Gets the name of this PatchedrpmUlnRemote.  # noqa: E501

        A unique name for this remote.  # noqa: E501

        :return: The name of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PatchedrpmUlnRemote.

        A unique name for this remote.  # noqa: E501

        :param name: The name of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def url(self):
        """Gets the url of this PatchedrpmUlnRemote.  # noqa: E501

        The ULN repo URL of the remote content source.\"This is \"uln://\" followed by the channel name. E.g.: \"uln://ol7_x86_64_oracle\"  # noqa: E501

        :return: The url of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PatchedrpmUlnRemote.

        The ULN repo URL of the remote content source.\"This is \"uln://\" followed by the channel name. E.g.: \"uln://ol7_x86_64_oracle\"  # noqa: E501

        :param url: The url of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                url is not None and len(url) < 1):
            raise ValueError("Invalid value for `url`, length must be greater than or equal to `1`")  # noqa: E501

        self._url = url

    @property
    def ca_cert(self):
        """Gets the ca_cert of this PatchedrpmUlnRemote.  # noqa: E501

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :return: The ca_cert of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert

    @ca_cert.setter
    def ca_cert(self, ca_cert):
        """Sets the ca_cert of this PatchedrpmUlnRemote.

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :param ca_cert: The ca_cert of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                ca_cert is not None and len(ca_cert) < 1):
            raise ValueError("Invalid value for `ca_cert`, length must be greater than or equal to `1`")  # noqa: E501

        self._ca_cert = ca_cert

    @property
    def client_cert(self):
        """Gets the client_cert of this PatchedrpmUlnRemote.  # noqa: E501

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :return: The client_cert of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._client_cert

    @client_cert.setter
    def client_cert(self, client_cert):
        """Sets the client_cert of this PatchedrpmUlnRemote.

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :param client_cert: The client_cert of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_cert is not None and len(client_cert) < 1):
            raise ValueError("Invalid value for `client_cert`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_cert = client_cert

    @property
    def client_key(self):
        """Gets the client_key of this PatchedrpmUlnRemote.  # noqa: E501

        A PEM encoded private key used for authentication.  # noqa: E501

        :return: The client_key of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._client_key

    @client_key.setter
    def client_key(self, client_key):
        """Sets the client_key of this PatchedrpmUlnRemote.

        A PEM encoded private key used for authentication.  # noqa: E501

        :param client_key: The client_key of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_key is not None and len(client_key) < 1):
            raise ValueError("Invalid value for `client_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_key = client_key

    @property
    def tls_validation(self):
        """Gets the tls_validation of this PatchedrpmUlnRemote.  # noqa: E501

        If True, TLS peer validation must be performed.  # noqa: E501

        :return: The tls_validation of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: bool
        """
        return self._tls_validation

    @tls_validation.setter
    def tls_validation(self, tls_validation):
        """Sets the tls_validation of this PatchedrpmUlnRemote.

        If True, TLS peer validation must be performed.  # noqa: E501

        :param tls_validation: The tls_validation of this PatchedrpmUlnRemote.  # noqa: E501
        :type: bool
        """

        self._tls_validation = tls_validation

    @property
    def proxy_url(self):
        """Gets the proxy_url of this PatchedrpmUlnRemote.  # noqa: E501

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :return: The proxy_url of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """Sets the proxy_url of this PatchedrpmUlnRemote.

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :param proxy_url: The proxy_url of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                proxy_url is not None and len(proxy_url) < 1):
            raise ValueError("Invalid value for `proxy_url`, length must be greater than or equal to `1`")  # noqa: E501

        self._proxy_url = proxy_url

    @property
    def proxy_username(self):
        """Gets the proxy_username of this PatchedrpmUlnRemote.  # noqa: E501

        The username to authenticte to the proxy.  # noqa: E501

        :return: The proxy_username of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._proxy_username

    @proxy_username.setter
    def proxy_username(self, proxy_username):
        """Sets the proxy_username of this PatchedrpmUlnRemote.

        The username to authenticte to the proxy.  # noqa: E501

        :param proxy_username: The proxy_username of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                proxy_username is not None and len(proxy_username) < 1):
            raise ValueError("Invalid value for `proxy_username`, length must be greater than or equal to `1`")  # noqa: E501

        self._proxy_username = proxy_username

    @property
    def proxy_password(self):
        """Gets the proxy_password of this PatchedrpmUlnRemote.  # noqa: E501

        The password to authenticate to the proxy. Extra leading and trailing whitespace characters are not trimmed.  # noqa: E501

        :return: The proxy_password of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._proxy_password

    @proxy_password.setter
    def proxy_password(self, proxy_password):
        """Sets the proxy_password of this PatchedrpmUlnRemote.

        The password to authenticate to the proxy. Extra leading and trailing whitespace characters are not trimmed.  # noqa: E501

        :param proxy_password: The proxy_password of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                proxy_password is not None and len(proxy_password) < 1):
            raise ValueError("Invalid value for `proxy_password`, length must be greater than or equal to `1`")  # noqa: E501

        self._proxy_password = proxy_password

    @property
    def username(self):
        """Gets the username of this PatchedrpmUlnRemote.  # noqa: E501

        Your ULN account username.  # noqa: E501

        :return: The username of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this PatchedrpmUlnRemote.

        Your ULN account username.  # noqa: E501

        :param username: The username of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) < 1):
            raise ValueError("Invalid value for `username`, length must be greater than or equal to `1`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this PatchedrpmUlnRemote.  # noqa: E501

        Your ULN account password.  # noqa: E501

        :return: The password of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this PatchedrpmUlnRemote.

        Your ULN account password.  # noqa: E501

        :param password: The password of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                password is not None and len(password) < 1):
            raise ValueError("Invalid value for `password`, length must be greater than or equal to `1`")  # noqa: E501

        self._password = password

    @property
    def pulp_labels(self):
        """Gets the pulp_labels of this PatchedrpmUlnRemote.  # noqa: E501


        :return: The pulp_labels of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._pulp_labels

    @pulp_labels.setter
    def pulp_labels(self, pulp_labels):
        """Sets the pulp_labels of this PatchedrpmUlnRemote.


        :param pulp_labels: The pulp_labels of this PatchedrpmUlnRemote.  # noqa: E501
        :type: dict(str, str)
        """

        self._pulp_labels = pulp_labels

    @property
    def download_concurrency(self):
        """Gets the download_concurrency of this PatchedrpmUlnRemote.  # noqa: E501

        Total number of simultaneous connections. If not set then the default value will be used.  # noqa: E501

        :return: The download_concurrency of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: int
        """
        return self._download_concurrency

    @download_concurrency.setter
    def download_concurrency(self, download_concurrency):
        """Sets the download_concurrency of this PatchedrpmUlnRemote.

        Total number of simultaneous connections. If not set then the default value will be used.  # noqa: E501

        :param download_concurrency: The download_concurrency of this PatchedrpmUlnRemote.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                download_concurrency is not None and download_concurrency < 1):  # noqa: E501
            raise ValueError("Invalid value for `download_concurrency`, must be a value greater than or equal to `1`")  # noqa: E501

        self._download_concurrency = download_concurrency

    @property
    def max_retries(self):
        """Gets the max_retries of this PatchedrpmUlnRemote.  # noqa: E501

        Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.  # noqa: E501

        :return: The max_retries of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: int
        """
        return self._max_retries

    @max_retries.setter
    def max_retries(self, max_retries):
        """Sets the max_retries of this PatchedrpmUlnRemote.

        Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.  # noqa: E501

        :param max_retries: The max_retries of this PatchedrpmUlnRemote.  # noqa: E501
        :type: int
        """

        self._max_retries = max_retries

    @property
    def policy(self):
        """Gets the policy of this PatchedrpmUlnRemote.  # noqa: E501

        The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.  # noqa: E501

        :return: The policy of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: PolicyEnum
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this PatchedrpmUlnRemote.

        The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.  # noqa: E501

        :param policy: The policy of this PatchedrpmUlnRemote.  # noqa: E501
        :type: PolicyEnum
        """

        self._policy = policy

    @property
    def total_timeout(self):
        """Gets the total_timeout of this PatchedrpmUlnRemote.  # noqa: E501

        aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The total_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: float
        """
        return self._total_timeout

    @total_timeout.setter
    def total_timeout(self, total_timeout):
        """Sets the total_timeout of this PatchedrpmUlnRemote.

        aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param total_timeout: The total_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                total_timeout is not None and total_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `total_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._total_timeout = total_timeout

    @property
    def connect_timeout(self):
        """Gets the connect_timeout of this PatchedrpmUlnRemote.  # noqa: E501

        aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The connect_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: float
        """
        return self._connect_timeout

    @connect_timeout.setter
    def connect_timeout(self, connect_timeout):
        """Sets the connect_timeout of this PatchedrpmUlnRemote.

        aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param connect_timeout: The connect_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                connect_timeout is not None and connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._connect_timeout = connect_timeout

    @property
    def sock_connect_timeout(self):
        """Gets the sock_connect_timeout of this PatchedrpmUlnRemote.  # noqa: E501

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The sock_connect_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: float
        """
        return self._sock_connect_timeout

    @sock_connect_timeout.setter
    def sock_connect_timeout(self, sock_connect_timeout):
        """Sets the sock_connect_timeout of this PatchedrpmUlnRemote.

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param sock_connect_timeout: The sock_connect_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_connect_timeout is not None and sock_connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_connect_timeout = sock_connect_timeout

    @property
    def sock_read_timeout(self):
        """Gets the sock_read_timeout of this PatchedrpmUlnRemote.  # noqa: E501

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The sock_read_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: float
        """
        return self._sock_read_timeout

    @sock_read_timeout.setter
    def sock_read_timeout(self, sock_read_timeout):
        """Sets the sock_read_timeout of this PatchedrpmUlnRemote.

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param sock_read_timeout: The sock_read_timeout of this PatchedrpmUlnRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_read_timeout is not None and sock_read_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_read_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_read_timeout = sock_read_timeout

    @property
    def headers(self):
        """Gets the headers of this PatchedrpmUlnRemote.  # noqa: E501

        Headers for aiohttp.Clientsession  # noqa: E501

        :return: The headers of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: list[object]
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this PatchedrpmUlnRemote.

        Headers for aiohttp.Clientsession  # noqa: E501

        :param headers: The headers of this PatchedrpmUlnRemote.  # noqa: E501
        :type: list[object]
        """

        self._headers = headers

    @property
    def rate_limit(self):
        """Gets the rate_limit of this PatchedrpmUlnRemote.  # noqa: E501

        Limits requests per second for each concurrent downloader  # noqa: E501

        :return: The rate_limit of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit

    @rate_limit.setter
    def rate_limit(self, rate_limit):
        """Sets the rate_limit of this PatchedrpmUlnRemote.

        Limits requests per second for each concurrent downloader  # noqa: E501

        :param rate_limit: The rate_limit of this PatchedrpmUlnRemote.  # noqa: E501
        :type: int
        """

        self._rate_limit = rate_limit

    @property
    def uln_server_base_url(self):
        """Gets the uln_server_base_url of this PatchedrpmUlnRemote.  # noqa: E501

        Base URL of the ULN server. If the uln_server_base_url is not provided pulp_rpm willuse the contents of the DEFAULT_ULN_SERVER_BASE_URL setting instead.  # noqa: E501

        :return: The uln_server_base_url of this PatchedrpmUlnRemote.  # noqa: E501
        :rtype: str
        """
        return self._uln_server_base_url

    @uln_server_base_url.setter
    def uln_server_base_url(self, uln_server_base_url):
        """Sets the uln_server_base_url of this PatchedrpmUlnRemote.

        Base URL of the ULN server. If the uln_server_base_url is not provided pulp_rpm willuse the contents of the DEFAULT_ULN_SERVER_BASE_URL setting instead.  # noqa: E501

        :param uln_server_base_url: The uln_server_base_url of this PatchedrpmUlnRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                uln_server_base_url is not None and len(uln_server_base_url) < 1):
            raise ValueError("Invalid value for `uln_server_base_url`, length must be greater than or equal to `1`")  # noqa: E501

        self._uln_server_base_url = uln_server_base_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchedrpmUlnRemote):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PatchedrpmUlnRemote):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmDistributionTreeResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'header_version': 'str',
        'release_name': 'str',
        'release_short': 'str',
        'release_version': 'str',
        'release_is_layered': 'bool',
        'base_product_name': 'str',
        'base_product_short': 'str',
        'base_product_version': 'str',
        'arch': 'str',
        'build_timestamp': 'float',
        'instimage': 'str',
        'mainimage': 'str',
        'discnum': 'int',
        'totaldiscs': 'int',
        'addons': 'list[AddonResponse]',
        'checksums': 'list[ChecksumResponse]',
        'images': 'list[ImageResponse]',
        'variants': 'list[VariantResponse]'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'header_version': 'header_version',
        'release_name': 'release_name',
        'release_short': 'release_short',
        'release_version': 'release_version',
        'release_is_layered': 'release_is_layered',
        'base_product_name': 'base_product_name',
        'base_product_short': 'base_product_short',
        'base_product_version': 'base_product_version',
        'arch': 'arch',
        'build_timestamp': 'build_timestamp',
        'instimage': 'instimage',
        'mainimage': 'mainimage',
        'discnum': 'discnum',
        'totaldiscs': 'totaldiscs',
        'addons': 'addons',
        'checksums': 'checksums',
        'images': 'images',
        'variants': 'variants'
    }

    def __init__(self, pulp_href=None, header_version=None, release_name=None, release_short=None, release_version=None, release_is_layered=None, base_product_name=None, base_product_short=None, base_product_version=None, arch=None, build_timestamp=None, instimage=None, mainimage=None, discnum=None, totaldiscs=None, addons=None, checksums=None, images=None, variants=None, local_vars_configuration=None):  # noqa: E501
        """RpmDistributionTreeResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._header_version = None
        self._release_name = None
        self._release_short = None
        self._release_version = None
        self._release_is_layered = None
        self._base_product_name = None
        self._base_product_short = None
        self._base_product_version = None
        self._arch = None
        self._build_timestamp = None
        self._instimage = None
        self._mainimage = None
        self._discnum = None
        self._totaldiscs = None
        self._addons = None
        self._checksums = None
        self._images = None
        self._variants = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        self.header_version = header_version
        self.release_name = release_name
        self.release_short = release_short
        self.release_version = release_version
        self.release_is_layered = release_is_layered
        self.base_product_name = base_product_name
        self.base_product_short = base_product_short
        self.base_product_version = base_product_version
        self.arch = arch
        self.build_timestamp = build_timestamp
        self.instimage = instimage
        self.mainimage = mainimage
        self.discnum = discnum
        self.totaldiscs = totaldiscs
        self.addons = addons
        self.checksums = checksums
        self.images = images
        self.variants = variants

    @property
    def pulp_href(self):
        """Gets the pulp_href of this RpmDistributionTreeResponse.  # noqa: E501


        :return: The pulp_href of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this RpmDistributionTreeResponse.


        :param pulp_href: The pulp_href of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def header_version(self):
        """Gets the header_version of this RpmDistributionTreeResponse.  # noqa: E501

        Header Version.  # noqa: E501

        :return: The header_version of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._header_version

    @header_version.setter
    def header_version(self, header_version):
        """Sets the header_version of this RpmDistributionTreeResponse.

        Header Version.  # noqa: E501

        :param header_version: The header_version of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and header_version is None:  # noqa: E501
            raise ValueError("Invalid value for `header_version`, must not be `None`")  # noqa: E501

        self._header_version = header_version

    @property
    def release_name(self):
        """Gets the release_name of this RpmDistributionTreeResponse.  # noqa: E501

        Release name.  # noqa: E501

        :return: The release_name of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._release_name

    @release_name.setter
    def release_name(self, release_name):
        """Sets the release_name of this RpmDistributionTreeResponse.

        Release name.  # noqa: E501

        :param release_name: The release_name of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and release_name is None:  # noqa: E501
            raise ValueError("Invalid value for `release_name`, must not be `None`")  # noqa: E501

        self._release_name = release_name

    @property
    def release_short(self):
        """Gets the release_short of this RpmDistributionTreeResponse.  # noqa: E501

        Release short name.  # noqa: E501

        :return: The release_short of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._release_short

    @release_short.setter
    def release_short(self, release_short):
        """Sets the release_short of this RpmDistributionTreeResponse.

        Release short name.  # noqa: E501

        :param release_short: The release_short of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and release_short is None:  # noqa: E501
            raise ValueError("Invalid value for `release_short`, must not be `None`")  # noqa: E501

        self._release_short = release_short

    @property
    def release_version(self):
        """Gets the release_version of this RpmDistributionTreeResponse.  # noqa: E501

        Release version.  # noqa: E501

        :return: The release_version of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._release_version

    @release_version.setter
    def release_version(self, release_version):
        """Sets the release_version of this RpmDistributionTreeResponse.

        Release version.  # noqa: E501

        :param release_version: The release_version of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and release_version is None:  # noqa: E501
            raise ValueError("Invalid value for `release_version`, must not be `None`")  # noqa: E501

        self._release_version = release_version

    @property
    def release_is_layered(self):
        """Gets the release_is_layered of this RpmDistributionTreeResponse.  # noqa: E501

        Typically False for an operating system, True otherwise.  # noqa: E501

        :return: The release_is_layered of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: bool
        """
        return self._release_is_layered

    @release_is_layered.setter
    def release_is_layered(self, release_is_layered):
        """Sets the release_is_layered of this RpmDistributionTreeResponse.

        Typically False for an operating system, True otherwise.  # noqa: E501

        :param release_is_layered: The release_is_layered of this RpmDistributionTreeResponse.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and release_is_layered is None:  # noqa: E501
            raise ValueError("Invalid value for `release_is_layered`, must not be `None`")  # noqa: E501

        self._release_is_layered = release_is_layered

    @property
    def base_product_name(self):
        """Gets the base_product_name of this RpmDistributionTreeResponse.  # noqa: E501

        Base Product name.  # noqa: E501

        :return: The base_product_name of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._base_product_name

    @base_product_name.setter
    def base_product_name(self, base_product_name):
        """Sets the base_product_name of this RpmDistributionTreeResponse.

        Base Product name.  # noqa: E501

        :param base_product_name: The base_product_name of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """

        self._base_product_name = base_product_name

    @property
    def base_product_short(self):
        """Gets the base_product_short of this RpmDistributionTreeResponse.  # noqa: E501

        Base Product short name.  # noqa: E501

        :return: The base_product_short of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._base_product_short

    @base_product_short.setter
    def base_product_short(self, base_product_short):
        """Sets the base_product_short of this RpmDistributionTreeResponse.

        Base Product short name.  # noqa: E501

        :param base_product_short: The base_product_short of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """

        self._base_product_short = base_product_short

    @property
    def base_product_version(self):
        """Gets the base_product_version of this RpmDistributionTreeResponse.  # noqa: E501

        Base Product version.  # noqa: E501

        :return: The base_product_version of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._base_product_version

    @base_product_version.setter
    def base_product_version(self, base_product_version):
        """Sets the base_product_version of this RpmDistributionTreeResponse.

        Base Product version.  # noqa: E501

        :param base_product_version: The base_product_version of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """

        self._base_product_version = base_product_version

    @property
    def arch(self):
        """Gets the arch of this RpmDistributionTreeResponse.  # noqa: E501

        Tree architecturerch.  # noqa: E501

        :return: The arch of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._arch

    @arch.setter
    def arch(self, arch):
        """Sets the arch of this RpmDistributionTreeResponse.

        Tree architecturerch.  # noqa: E501

        :param arch: The arch of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and arch is None:  # noqa: E501
            raise ValueError("Invalid value for `arch`, must not be `None`")  # noqa: E501

        self._arch = arch

    @property
    def build_timestamp(self):
        """Gets the build_timestamp of this RpmDistributionTreeResponse.  # noqa: E501

        Tree build time timestamp.  # noqa: E501

        :return: The build_timestamp of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: float
        """
        return self._build_timestamp

    @build_timestamp.setter
    def build_timestamp(self, build_timestamp):
        """Sets the build_timestamp of this RpmDistributionTreeResponse.

        Tree build time timestamp.  # noqa: E501

        :param build_timestamp: The build_timestamp of this RpmDistributionTreeResponse.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and build_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `build_timestamp`, must not be `None`")  # noqa: E501

        self._build_timestamp = build_timestamp

    @property
    def instimage(self):
        """Gets the instimage of this RpmDistributionTreeResponse.  # noqa: E501

        Relative path to Anaconda instimage.  # noqa: E501

        :return: The instimage of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._instimage

    @instimage.setter
    def instimage(self, instimage):
        """Sets the instimage of this RpmDistributionTreeResponse.

        Relative path to Anaconda instimage.  # noqa: E501

        :param instimage: The instimage of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """

        self._instimage = instimage

    @property
    def mainimage(self):
        """Gets the mainimage of this RpmDistributionTreeResponse.  # noqa: E501

        Relative path to Anaconda stage2 image.  # noqa: E501

        :return: The mainimage of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: str
        """
        return self._mainimage

    @mainimage.setter
    def mainimage(self, mainimage):
        """Sets the mainimage of this RpmDistributionTreeResponse.

        Relative path to Anaconda stage2 image.  # noqa: E501

        :param mainimage: The mainimage of this RpmDistributionTreeResponse.  # noqa: E501
        :type: str
        """

        self._mainimage = mainimage

    @property
    def discnum(self):
        """Gets the discnum of this RpmDistributionTreeResponse.  # noqa: E501

        Disc number.  # noqa: E501

        :return: The discnum of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: int
        """
        return self._discnum

    @discnum.setter
    def discnum(self, discnum):
        """Sets the discnum of this RpmDistributionTreeResponse.

        Disc number.  # noqa: E501

        :param discnum: The discnum of this RpmDistributionTreeResponse.  # noqa: E501
        :type: int
        """

        self._discnum = discnum

    @property
    def totaldiscs(self):
        """Gets the totaldiscs of this RpmDistributionTreeResponse.  # noqa: E501

        Number of discs in media set.  # noqa: E501

        :return: The totaldiscs of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: int
        """
        return self._totaldiscs

    @totaldiscs.setter
    def totaldiscs(self, totaldiscs):
        """Sets the totaldiscs of this RpmDistributionTreeResponse.

        Number of discs in media set.  # noqa: E501

        :param totaldiscs: The totaldiscs of this RpmDistributionTreeResponse.  # noqa: E501
        :type: int
        """

        self._totaldiscs = totaldiscs

    @property
    def addons(self):
        """Gets the addons of this RpmDistributionTreeResponse.  # noqa: E501


        :return: The addons of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: list[AddonResponse]
        """
        return self._addons

    @addons.setter
    def addons(self, addons):
        """Sets the addons of this RpmDistributionTreeResponse.


        :param addons: The addons of this RpmDistributionTreeResponse.  # noqa: E501
        :type: list[AddonResponse]
        """
        if self.local_vars_configuration.client_side_validation and addons is None:  # noqa: E501
            raise ValueError("Invalid value for `addons`, must not be `None`")  # noqa: E501

        self._addons = addons

    @property
    def checksums(self):
        """Gets the checksums of this RpmDistributionTreeResponse.  # noqa: E501


        :return: The checksums of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: list[ChecksumResponse]
        """
        return self._checksums

    @checksums.setter
    def checksums(self, checksums):
        """Sets the checksums of this RpmDistributionTreeResponse.


        :param checksums: The checksums of this RpmDistributionTreeResponse.  # noqa: E501
        :type: list[ChecksumResponse]
        """
        if self.local_vars_configuration.client_side_validation and checksums is None:  # noqa: E501
            raise ValueError("Invalid value for `checksums`, must not be `None`")  # noqa: E501

        self._checksums = checksums

    @property
    def images(self):
        """Gets the images of this RpmDistributionTreeResponse.  # noqa: E501


        :return: The images of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: list[ImageResponse]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this RpmDistributionTreeResponse.


        :param images: The images of this RpmDistributionTreeResponse.  # noqa: E501
        :type: list[ImageResponse]
        """
        if self.local_vars_configuration.client_side_validation and images is None:  # noqa: E501
            raise ValueError("Invalid value for `images`, must not be `None`")  # noqa: E501

        self._images = images

    @property
    def variants(self):
        """Gets the variants of this RpmDistributionTreeResponse.  # noqa: E501


        :return: The variants of this RpmDistributionTreeResponse.  # noqa: E501
        :rtype: list[VariantResponse]
        """
        return self._variants

    @variants.setter
    def variants(self, variants):
        """Sets the variants of this RpmDistributionTreeResponse.


        :param variants: The variants of this RpmDistributionTreeResponse.  # noqa: E501
        :type: list[VariantResponse]
        """
        if self.local_vars_configuration.client_side_validation and variants is None:  # noqa: E501
            raise ValueError("Invalid value for `variants`, must not be `None`")  # noqa: E501

        self._variants = variants

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmDistributionTreeResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmDistributionTreeResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmUlnRemoteResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'name': 'str',
        'url': 'str',
        'ca_cert': 'str',
        'client_cert': 'str',
        'tls_validation': 'bool',
        'proxy_url': 'str',
        'pulp_labels': 'dict(str, str)',
        'pulp_last_updated': 'datetime',
        'download_concurrency': 'int',
        'max_retries': 'int',
        'policy': 'PolicyEnum',
        'total_timeout': 'float',
        'connect_timeout': 'float',
        'sock_connect_timeout': 'float',
        'sock_read_timeout': 'float',
        'headers': 'list[object]',
        'rate_limit': 'int',
        'hidden_fields': 'list[RpmRpmRemoteResponseHiddenFields]',
        'uln_server_base_url': 'str'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'name': 'name',
        'url': 'url',
        'ca_cert': 'ca_cert',
        'client_cert': 'client_cert',
        'tls_validation': 'tls_validation',
        'proxy_url': 'proxy_url',
        'pulp_labels': 'pulp_labels',
        'pulp_last_updated': 'pulp_last_updated',
        'download_concurrency': 'download_concurrency',
        'max_retries': 'max_retries',
        'policy': 'policy',
        'total_timeout': 'total_timeout',
        'connect_timeout': 'connect_timeout',
        'sock_connect_timeout': 'sock_connect_timeout',
        'sock_read_timeout': 'sock_read_timeout',
        'headers': 'headers',
        'rate_limit': 'rate_limit',
        'hidden_fields': 'hidden_fields',
        'uln_server_base_url': 'uln_server_base_url'
    }

    def __init__(self, pulp_href=None, pulp_created=None, name=None, url=None, ca_cert=None, client_cert=None, tls_validation=None, proxy_url=None, pulp_labels=None, pulp_last_updated=None, download_concurrency=None, max_retries=None, policy=None, total_timeout=None, connect_timeout=None, sock_connect_timeout=None, sock_read_timeout=None, headers=None, rate_limit=None, hidden_fields=None, uln_server_base_url=None, local_vars_configuration=None):  # noqa: E501
        """RpmUlnRemoteResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._name = None
        self._url = None
        self._ca_cert = None
        self._client_cert = None
        self._tls_validation = None
        self._proxy_url = None
        self._pulp_labels = None
        self._pulp_last_updated = None
        self._download_concurrency = None
        self._max_retries = None
        self._policy = None
        self._total_timeout = None
        self._connect_timeout = None
        self._sock_connect_timeout = None
        self._sock_read_timeout = None
        self._headers = None
        self._rate_limit = None
        self._hidden_fields = None
        self._uln_server_base_url = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        self.name = name
        self.url = url
        self.ca_cert = ca_cert
        self.client_cert = client_cert
        if tls_validation is not None:
            self.tls_validation = tls_validation
        self.proxy_url = proxy_url
        if pulp_labels is not None:
            self.pulp_labels = pulp_labels
        if pulp_last_updated is not None:
            self.pulp_last_updated = pulp_last_updated
        self.download_concurrency = download_concurrency
        self.max_retries = max_retries
        if policy is not None:
            self.policy = policy
        self.total_timeout = total_timeout
        self.connect_timeout = connect_timeout
        self.sock_connect_timeout = sock_connect_timeout
        self.sock_read_timeout = sock_read_timeout
        if headers is not None:
            self.headers = headers
        self.rate_limit = rate_limit
        if hidden_fields is not None:
            self.hidden_fields = hidden_fields
        self.uln_server_base_url = uln_server_base_url

    @property
    def pulp_href(self):
        """Gets the pulp_href of this RpmUlnRemoteResponse.  # noqa: E501


        :return: The pulp_href of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this RpmUlnRemoteResponse.


        :param pulp_href: The pulp_href of this RpmUlnRemoteResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this RpmUlnRemoteResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this RpmUlnRemoteResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this RpmUlnRemoteResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def name(self):
        """Gets the name of this RpmUlnRemoteResponse.  # noqa: E501

        A unique name for this remote.  # noqa: E501

        :return: The name of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RpmUlnRemoteResponse.

        A unique name for this remote.  # noqa: E501

        :param name: The name of this RpmUlnRemoteResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def url(self):
        """Gets the url of this RpmUlnRemoteResponse.  # noqa: E501

        The ULN repo URL of the remote content source.\"This is \"uln://\" followed by the channel name. E.g.: \"uln://ol7_x86_64_oracle\"  # noqa: E501

        :return: The url of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this RpmUlnRemoteResponse.

        The ULN repo URL of the remote content source.\"This is \"uln://\" followed by the channel name. E.g.: \"uln://ol7_x86_64_oracle\"  # noqa: E501

        :param url: The url of this RpmUlnRemoteResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def ca_cert(self):
        """Gets the ca_cert of this RpmUlnRemoteResponse.  # noqa: E501

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :return: The ca_cert of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert

    @ca_cert.setter
    def ca_cert(self, ca_cert):
        """Sets the ca_cert of this RpmUlnRemoteResponse.

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :param ca_cert: The ca_cert of this RpmUlnRemoteResponse.  # noqa: E501
        :type: str
        """

        self._ca_cert = ca_cert

    @property
    def client_cert(self):
        """Gets the client_cert of this RpmUlnRemoteResponse.  # noqa: E501

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :return: The client_cert of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._client_cert

    @client_cert.setter
    def client_cert(self, client_cert):
        """Sets the client_cert of this RpmUlnRemoteResponse.

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :param client_cert: The client_cert of this RpmUlnRemoteResponse.  # noqa: E501
        :type: str
        """

        self._client_cert = client_cert

    @property
    def tls_validation(self):
        """Gets the tls_validation of this RpmUlnRemoteResponse.  # noqa: E501

        If True, TLS peer validation must be performed.  # noqa: E501

        :return: The tls_validation of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: bool
        """
        return self._tls_validation

    @tls_validation.setter
    def tls_validation(self, tls_validation):
        """Sets the tls_validation of this RpmUlnRemoteResponse.

        If True, TLS peer validation must be performed.  # noqa: E501

        :param tls_validation: The tls_validation of this RpmUlnRemoteResponse.  # noqa: E501
        :type: bool
        """

        self._tls_validation = tls_validation

    @property
    def proxy_url(self):
        """Gets the proxy_url of this RpmUlnRemoteResponse.  # noqa: E501

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :return: The proxy_url of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """Sets the proxy_url of this RpmUlnRemoteResponse.

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :param proxy_url: The proxy_url of this RpmUlnRemoteResponse.  # noqa: E501
        :type: str
        """

        self._proxy_url = proxy_url

    @property
    def pulp_labels(self):
        """Gets the pulp_labels of this RpmUlnRemoteResponse.  # noqa: E501


        :return: The pulp_labels of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._pulp_labels

    @pulp_labels.setter
    def pulp_labels(self, pulp_labels):
        """Sets the pulp_labels of this RpmUlnRemoteResponse.


        :param pulp_labels: The pulp_labels of this RpmUlnRemoteResponse.  # noqa: E501
        :type: dict(str, str)
        """

        self._pulp_labels = pulp_labels

    @property
    def pulp_last_updated(self):
        """Gets the pulp_last_updated of this RpmUlnRemoteResponse.  # noqa: E501

        Timestamp of the most recent update of the remote.  # noqa: E501

        :return: The pulp_last_updated of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_last_updated

    @pulp_last_updated.setter
    def pulp_last_updated(self, pulp_last_updated):
        """Sets the pulp_last_updated of this RpmUlnRemoteResponse.

        Timestamp of the most recent update of the remote.  # noqa: E501

        :param pulp_last_updated: The pulp_last_updated of this RpmUlnRemoteResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_last_updated = pulp_last_updated

    @property
    def download_concurrency(self):
        """Gets the download_concurrency of this RpmUlnRemoteResponse.  # noqa: E501

        Total number of simultaneous connections. If not set then the default value will be used.  # noqa: E501

        :return: The download_concurrency of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: int
        """
        return self._download_concurrency

    @download_concurrency.setter
    def download_concurrency(self, download_concurrency):
        """Sets the download_concurrency of this RpmUlnRemoteResponse.

        Total number of simultaneous connections. If not set then the default value will be used.  # noqa: E501

        :param download_concurrency: The download_concurrency of this RpmUlnRemoteResponse.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                download_concurrency is not None and download_concurrency < 1):  # noqa: E501
            raise ValueError("Invalid value for `download_concurrency`, must be a value greater than or equal to `1`")  # noqa: E501

        self._download_concurrency = download_concurrency

    @property
    def max_retries(self):
        """Gets the max_retries of this RpmUlnRemoteResponse.  # noqa: E501

        Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.  # noqa: E501

        :return: The max_retries of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: int
        """
        return self._max_retries

    @max_retries.setter
    def max_retries(self, max_retries):
        """Sets the max_retries of this RpmUlnRemoteResponse.

        Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.  # noqa: E501

        :param max_retries: The max_retries of this RpmUlnRemoteResponse.  # noqa: E501
        :type: int
        """

        self._max_retries = max_retries

    @property
    def policy(self):
        """Gets the policy of this RpmUlnRemoteResponse.  # noqa: E501

        The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.  # noqa: E501

        :return: The policy of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: PolicyEnum
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this RpmUlnRemoteResponse.

        The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.  # noqa: E501

        :param policy: The policy of this RpmUlnRemoteResponse.  # noqa: E501
        :type: PolicyEnum
        """

        self._policy = policy

    @property
    def total_timeout(self):
        """Gets the total_timeout of this RpmUlnRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The total_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_timeout

    @total_timeout.setter
    def total_timeout(self, total_timeout):
        """Sets the total_timeout of this RpmUlnRemoteResponse.

        aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param total_timeout: The total_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                total_timeout is not None and total_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `total_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._total_timeout = total_timeout

    @property
    def connect_timeout(self):
        """Gets the connect_timeout of this RpmUlnRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The connect_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._connect_timeout

    @connect_timeout.setter
    def connect_timeout(self, connect_timeout):
        """Sets the connect_timeout of this RpmUlnRemoteResponse.

        aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param connect_timeout: The connect_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                connect_timeout is not None and connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._connect_timeout = connect_timeout

    @property
    def sock_connect_timeout(self):
        """Gets the sock_connect_timeout of this RpmUlnRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The sock_connect_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._sock_connect_timeout

    @sock_connect_timeout.setter
    def sock_connect_timeout(self, sock_connect_timeout):
        """Sets the sock_connect_timeout of this RpmUlnRemoteResponse.

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param sock_connect_timeout: The sock_connect_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_connect_timeout is not None and sock_connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_connect_timeout = sock_connect_timeout

    @property
    def sock_read_timeout(self):
        """Gets the sock_read_timeout of this RpmUlnRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The sock_read_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._sock_read_timeout

    @sock_read_timeout.setter
    def sock_read_timeout(self, sock_read_timeout):
        """Sets the sock_read_timeout of this RpmUlnRemoteResponse.

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param sock_read_timeout: The sock_read_timeout of this RpmUlnRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_read_timeout is not None and sock_read_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_read_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_read_timeout = sock_read_timeout

    @property
    def headers(self):
        """Gets the headers of this RpmUlnRemoteResponse.  # noqa: E501

        Headers for aiohttp.Clientsession  # noqa: E501

        :return: The headers of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: list[object]
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this RpmUlnRemoteResponse.

        Headers for aiohttp.Clientsession  # noqa: E501

        :param headers: The headers of this RpmUlnRemoteResponse.  # noqa: E501
        :type: list[object]
        """

        self._headers = headers

    @property
    def rate_limit(self):
        """Gets the rate_limit of this RpmUlnRemoteResponse.  # noqa: E501

        Limits requests per second for each concurrent downloader  # noqa: E501

        :return: The rate_limit of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit

    @rate_limit.setter
    def rate_limit(self, rate_limit):
        """Sets the rate_limit of this RpmUlnRemoteResponse.

        Limits requests per second for each concurrent downloader  # noqa: E501

        :param rate_limit: The rate_limit of this RpmUlnRemoteResponse.  # noqa: E501
        :type: int
        """

        self._rate_limit = rate_limit

    @property
    def hidden_fields(self):
        """Gets the hidden_fields of this RpmUlnRemoteResponse.  # noqa: E501

        List of hidden (write only) fields  # noqa: E501

        :return: The hidden_fields of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: list[RpmRpmRemoteResponseHiddenFields]
        """
        return self._hidden_fields

    @hidden_fields.setter
    def hidden_fields(self, hidden_fields):
        """Sets the hidden_fields of this RpmUlnRemoteResponse.

        List of hidden (write only) fields  # noqa: E501

        :param hidden_fields: The hidden_fields of this RpmUlnRemoteResponse.  # noqa: E501
        :type: list[RpmRpmRemoteResponseHiddenFields]
        """

        self._hidden_fields = hidden_fields

    @property
    def uln_server_base_url(self):
        """Gets the uln_server_base_url of this RpmUlnRemoteResponse.  # noqa: E501

        Base URL of the ULN server. If the uln_server_base_url is not provided pulp_rpm willuse the contents of the DEFAULT_ULN_SERVER_BASE_URL setting instead.  # noqa: E501

        :return: The uln_server_base_url of this RpmUlnRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._uln_server_base_url

    @uln_server_base_url.setter
    def uln_server_base_url(self, uln_server_base_url):
        """Sets the uln_server_base_url of this RpmUlnRemoteResponse.

        Base URL of the ULN server. If the uln_server_base_url is not provided pulp_rpm willuse the contents of the DEFAULT_ULN_SERVER_BASE_URL setting instead.  # noqa: E501

        :param uln_server_base_url: The uln_server_base_url of this RpmUlnRemoteResponse.  # noqa: E501
        :type: str
        """

        self._uln_server_base_url = uln_server_base_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmUlnRemoteResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmUlnRemoteResponse):
            return True

        return self.to_dict() != other.to_dict()
